@@ -8,63 +8,23 @@ use warnings;
 use Carp;
 use JSON;
 
-use Astro::SpaceTrack;
-use HTTP::Response;
-use HTTP::Status qw{ HTTP_OK };
-our @ISA = qw{ Astro::SpaceTrack };
+use base qw{ Astro::SpaceTrack };
 
-# NOTE that these live in inc/, but so does this module, so we assume
-# inc/ is already in @INC.
+eval {
+    local @INC = @INC;
+    require lib;
+    lib->import( 'inc' );
+    require Mock::LWP::UserAgent;
+    1;
+} or croak 'Can not load Mock::LWP::UserAgent. Code must be run from the base directory of the Astro-SpaceTrack distribution';
 
-use Mock::LWP::UserAgent;
-use My::Module::Test;
-
-our $VERSION = '0.179_002';
-
-sub new {
-    my ( $class, %arg ) = @_;
-    local $Mock::LWP::UserAgent::CANNED_RESPONSE_FILE = delete
-    $arg{canned_response_file};
-    my $self = $class->SUPER::new( %arg );
-    $self->{ +__PACKAGE__ } = Mock::LWP::UserAgent::__load_data(
-	optional	=> 1,
-    );
-    return $self;
-}
-
-sub site_check {
-    my ( $self, $site ) = @_;
-    my $uri = My::Module::Test::__site_to_check_uri( $site )
-	or die "No check URI for site '$site'\n";
-    return $self->_get_from_net( url => $uri );
-}
-
-sub _readline_complete_command_site_check {
-    # my ( $self, $text, $line, $start, $cmd_line ) = @_;
-    my ( $self, $text ) = @_;
-    my @sites = My::Module::Test::__site_codes();
-    $text eq ''
-	and return @sites;
-    my $re = qr/ \A \Q$text\E /smx;
-    return grep { $_ =~ $re } @sites;
-}
-
-sub request {
-    my ( $self, $method, $uri ) = @_;
-    defined $uri
-	or ( $method, $uri ) = ( GET => $method );
-    return $self->_get_from_net(
-	method	=> uc $method,
-	url	=> $uri,
-    );
-}
+our $VERSION = '0.087';
 
 {
     my $json;
     my $keep;
 
-    # Accessed via address space scan in _list_censors()
-    sub _censor_json {	## no critic (ProhibitUnusedPrivateSubroutines)
+    sub _censor_json {
 	my ( $data ) = @_;
 	$data =~ m/ \A \s* [[] \s* [{] .* [}] \s* []] \s* \z /smx
 	    or return;
@@ -100,37 +60,34 @@ sub request {
 		$keep->{$key}
 		    or delete $item->{$key};
 	    }
-	    defined $item->{TLE_LINE1}
-		and $item->{TLE_LINE1} =~ s/
+	    $item->{TLE_LINE1} =~ s/
 		    (?: \A | (?<= [\r\n] ) )
-		    ( 1 [\s0-9]{6}U \s )
+		    1 [\s0-9]{6}U \s \K
 		    [^\r\n]*
-		/${1}First line of data/smxg;
-	    defined $item->{TLE_LINE2}
-		and $item->{TLE_LINE2} =~ s/
+		/First line of data/smxg;
+	    $item->{TLE_LINE2} =~ s/
 		    (?: \A | (?<= [\r\n] ) )
-		    ( 2 [\s0-9]{6} \s )
+		    2 [\s0-9]{6} \s \K
 		    [^\r\n]*
-		/${1}Second line of data/smxg;
+		/Second line of data/smxg;
 	}
 	return $json->encode( $a );
     }
 }
 
-# Accessed via address space scan in _list_censors()
-sub _censor_tle {	## no critic (ProhibitUnusedPrivateSubroutines)
+sub _censor_tle {
     my ( $data ) = @_;
     $data =~ s/
 	(?: \A | (?<= [\r\n] ) )
-	( 1 [\s0-9]{6}U \s )
+	1 [\s0-9]{6}U \s \K
 	[^\r\n]*
-    /${1}First line of data/smxg
+    /First line of data/smxg
 	or return;
     $data =~ s/
 	(?: \A | (?<= [\r\n] ) )
-	( 2 [\s0-9]{6} \s )
+	2 [\s0-9]{6} \s \K
 	[^\r\n]*
-    /${1}Second line of data/smxg
+    /Second line of data/smxg
 	or return;
     return $data;
 }
@@ -148,6 +105,15 @@ sub _censor_tle {	## no critic (ProhibitUnusedPrivateSubroutines)
 	my $method = $rqst->method();
 	my $url = $rqst->url();
 
+	my $path = Mock::LWP::UserAgent::__file_name_for( $method, $url );
+	-e $path
+	    and return;
+
+	my $dump_flags = $self->getv( 'dump_headers' );
+	$dump_flags & $self->DUMP_RESPONSE
+	    and warn "Creating $path\n";
+
+	$json ||= JSON->new()->utf8()->pretty()->canonical();
 	$censors ||= _list_censors();
 	my $content = $resp->content();
 	foreach my $code ( @{ $censors } ) {
@@ -167,32 +133,21 @@ sub _censor_tle {	## no critic (ProhibitUnusedPrivateSubroutines)
 		_dump_header_item( $resp, 'Status' ),
 	    ],
 	    $content,
+	    {
+		method	=> $method,
+		uri		=> '' . $url,	# Stringify
+	    },
 	);
 
-	Mock::LWP::UserAgent::__modify_data(
-	    $self->{ +__PACKAGE__ }, $url, $method, \@data );
+	open my $fh, '>:encoding(utf-8)', $path
+	    or die "Unable to open $path: $!\n";
+	print { $fh } $json->encode( \@data );
+	close $fh;
 
 	return;
     }
 }
 
-sub list {
-    my ( $self ) = @_;
-    my $data = $self->{ +__PACKAGE__ }{data};
-    my @content;
-    foreach my $url ( sort keys %{ $data } ) {
-	foreach my $method ( sort keys %{ $data->{$url} } ) {
-	    push @content, "$method $url\r\n";
-	}
-    }
-    return HTTP::Response->new(
-	HTTP_OK,
-	undef,
-	undef,
-	join( '', @content ),
-    );
-}
-
 sub _dump_header_item {
     my ( $resp, $name, $override ) = @_;
     my @value = $resp->header( $name )
@@ -263,13 +218,17 @@ This class supports the following protected methods:
 
  $st->__dump_response( $resp );
 
-This override of the superclass' method adds the given response to the
-C<Mock::LWP::UserAgent> data file.
+This override of the superclass' method unconditionally checks the
+C<Mock::LWP::UserAgent> data directory to see if the
+C<HTTP::Response|HTTP::Response> object is represented there. If not, it
+is written. If the C<DUMP_HEADERS> bit is set, a message is written to
+standard error before a new file is created.
 
 =head1 ATTRIBUTES
 
 This class has no additional attributes.
 
+
 =head1 SEE ALSO
 
 L<Astro::SpaceTrack|Astro::SpaceTrack>.
@@ -277,9 +236,7 @@ L<Astro::SpaceTrack|Astro::SpaceTrack>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-SpaceTrack>,
-L<https://github.com/trwyant/perl-Astro-SpaceTrack/issues/>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -287,11 +244,11 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2026 by Thomas R. Wyant, III
+Copyright (C) 2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
-of the licenses in the files F<LICENSE-Artistic> and F<LICENSE-GPL>.
+of the licenses in the directory LICENSES.
 
 This program is distributed in the hope that it will be useful, but
 without any warranty; without even the implied warranty of
