@@ -19,6 +19,7 @@ sub new {
 
 sub build_requires {
     return +{
+	'File::Temp'	=> 0,
 ##	'Test::More'	=> 0.40,
 ##	'Test::More'	=> 0.88,	# Because of done_testing().
 	'Test::More'	=> 0.96,	# Because of subtest()
@@ -68,9 +69,12 @@ sub requires {
 	'Data::Dumper'		=> 0,
 	'Exporter'		=> 0,
 	'Getopt::Long'		=> 2.39,	# For getoptionsfromarray
+	'HTTP::Date'		=> 0,
+	'HTTP::Request'		=> 0,
 	'HTTP::Response'	=> 0,
 	'HTTP::Status'		=> 6.03,	# For the teapot status
 	'IO::File'		=> 0,
+	'IO::Uncompress::Unzip'	=> 0,	# For McCants
 	'JSON'			=> 0,	# For Space Track v2
 	'List::Util'		=> 0,	# For Space Track v2 FILE tracking
 	'LWP::UserAgent'	=> 0,
